Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3308)

Unified Diff: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompleteContactDetailsTest.java

Issue 2766413003: test (Closed)
Patch Set: format Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompleteContactDetailsTest.java
diff --git a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompleteContactDetailsTest.java b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompleteContactDetailsTest.java
index 6198c37c85a3710255490862a81d5e2abbd01fd5..996c24ba9ecbf2b65694401cd9e960d6dc6edce5 100644
--- a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompleteContactDetailsTest.java
+++ b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestIncompleteContactDetailsTest.java
@@ -54,9 +54,9 @@ public class PaymentRequestIncompleteContactDetailsTest extends PaymentRequestTe
clickInContactInfoAndWait(R.id.payments_first_radio_button, mReadyToEdit);
setTextInEditorAndWait(new String[] {"", "---", "jane.jones"}, mEditorTextUpdate);
clickInEditorAndWait(R.id.payments_edit_done_button, mEditorValidationError);
// The section collapses and the [SELECT] button is active.
clickInEditorAndWait(R.id.payments_edit_cancel_button, mReadyForInput);
- assertEquals(PaymentRequestSection.EDIT_BUTTON_SELECT, getContactDetailsButtonState());
+ assertEquals(PaymentRequestSection.EDIT_BUTTON_CHOOSE, getContactDetailsButtonState());
clickAndWait(R.id.close_button, mDismissed);
expectResultContains(new String[] {"Request cancelled"});
@@ -78,9 +78,9 @@ public class PaymentRequestIncompleteContactDetailsTest extends PaymentRequestTe
clickInContactInfoAndWait(R.id.payments_add_option_button, mReadyToEdit);
setTextInEditorAndWait(new String[] {"", "---", "jane.jones"}, mEditorTextUpdate);
clickInEditorAndWait(R.id.payments_edit_done_button, mEditorValidationError);
// The section collapses and the [SELECT] button is active.
clickInEditorAndWait(R.id.payments_edit_cancel_button, mReadyForInput);
- assertEquals(PaymentRequestSection.EDIT_BUTTON_SELECT, getContactDetailsButtonState());
+ assertEquals(PaymentRequestSection.EDIT_BUTTON_CHOOSE, getContactDetailsButtonState());
clickAndWait(R.id.close_button, mDismissed);
expectResultContains(new String[] {"Request cancelled"});
@@ -54,9 +54,9 @@ public class PaymentRequestIncompleteContactDetailsTest extends PaymentRequestTe
setTextInEditorAndWait(new String[] {"", "---", "jane.jones"}, mEditorTextUpdate);
clickInEditorAndWait(R.id.payments_edit_done_button, mEditorValidationError);
- // The section collapses and the [SELECT] button is active.
+ // The section collapses and the [CHOOSE] button is active.
clickInEditorAndWait(R.id.payments_edit_cancel_button, mReadyForInput);
@@ -78,9 +78,9 @@ public class PaymentRequestIncompleteContactDetailsTest extends PaymentRequestTe
setTextInEditorAndWait(new String[] {"", "---", "jane.jones"}, mEditorTextUpdate);
clickInEditorAndWait(R.id.payments_edit_done_button, mEditorValidationError);
- // The section collapses and the [SELECT] button is active.
+ // The section collapses and the [CHOOSE] button is active.
clickInEditorAndWait(R.id.payments_edit_cancel_button, mReadyForInput);

Powered by Google App Engine
This is Rietveld 408576698